@@ -20,6 +20,7 @@
 # USA.
 
 import logging
+from linaro_image_tools.utils import DEFAULT_LOGGER_NAME
 
 
 class NullHandler(logging.Handler):
@@ -28,4 +29,4 @@ class NullHandler(logging.Handler):
 
 
 h = NullHandler()
-logging.getLogger(__name__).addHandler(h)
+logging.getLogger(DEFAULT_LOGGER_NAME).addHandler(h)
